toggleLike method
Toggles the like status of a comment.
If the comment is currently liked, it will be unliked, and vice versa. The returned Comment will have updated Comment.isLiked and Comment.likeCount values.
commentId is the ID of the comment to toggle like for.
Returns the updated Comment with new like status, or null if the operation failed.
Implementation
Future<Comment?> toggleLike(String commentId) async {
return await service.toggleLikeComment(commentId);
}