CdxCommentsLocalizationsIt class

The translations for Italian (it).

Inheritance

Constructors

CdxCommentsLocalizationsIt([String locale = 'it'])

Properties

add_a_comment String
Placeholder text for comment input field
no setteroverride
answer String
Button text to reply to a comment
no setteroverride
answer_to String
Label showing who you are replying to
no setteroverride
block_user String
Checkbox label for blocking a user
no setteroverride
blocked_until String
Label showing when user is blocked until
no setteroverride
cancel String
Cancel button text
no setteroverride
comment_bad_words String
Error message when comment contains bad words
no setteroverride
comment_dangerous String
Error message when comment contains dangerous content
no setteroverride
comment_empty String
Error message when comment is empty
no setteroverride
comments String
Title for comments section
no setteroverride
confirm String
Confirm button text
no setteroverride
delete String
Delete action label
no setteroverride
delete_comment String
Title for delete comment dialog
no setteroverride
end String
Submit button text
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
load_more_replies String
Button to load next page of replies
no setteroverride
localeName String
finalinherited
next String
Next button text
no setteroverride
q_delete_comment String
Confirmation question for deleting a comment
no setteroverride
q_report_comment String
Question for reporting a comment
no setteroverride
q_report_user String
Question for reporting a user
no setteroverride
report String
Report action label
no setteroverride
report_done String
Success message after submitting a report
no setteroverride
report_user String
Checkbox label for reporting a user
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

comment_too_long(int maxLength) String
Error message when comment is too long
override
comment_too_many_lines(int maxLines) String
Error message when comment has too many lines
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
view_replies(int count) String
Button text to view replies
override

Operators

operator ==(Object other) bool
The equality operator.
inherited