isMine property
Whether this comment was created by the current user.
This is a UI-only property, not present in the API response. Used to determine if the user can edit/delete this comment.
Implementation
final bool isMine;
Whether this comment was created by the current user.
This is a UI-only property, not present in the API response. Used to determine if the user can edit/delete this comment.
final bool isMine;