likeCount property
Number of likes this comment has received.
Can be null if likes are not enabled or not yet loaded.
Implementation
final int? likeCount;
Number of likes this comment has received.
Can be null if likes are not enabled or not yet loaded.
final int? likeCount;