parentId property
ID of the parent comment, if this is a reply.
null for root comments, non-null for replies.
Implementation
final String? parentId;
ID of the parent comment, if this is a reply.
null for root comments, non-null for replies.
final String? parentId;