CommentConfig class

Configuration for the comments module.

This class holds configuration settings that affect comment behavior, such as the list of bad words to filter.

Example:

const config = CommentConfig(
  badWords: 'bad\nword\ntest\n# This is a comment',
);

Constructors

CommentConfig({required String badWords})
Creates a new CommentConfig.
const

Properties

badWords String
Newline-separated list of bad words to filter.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited