buildCommentAvatar abstract method
Builds a custom avatar widget for the given comment.
Return null to fallback to the default avatar.
Implementation
Widget? buildCommentAvatar(BuildContext context, Comment comment);
Builds a custom avatar widget for the given comment.
Return null to fallback to the default avatar.
Widget? buildCommentAvatar(BuildContext context, Comment comment);