buildUserAvatar abstract method
Builds a custom avatar widget for the current user (used in the input field).
Return null to fallback to the default avatar.
Implementation
Widget? buildUserAvatar(BuildContext context, UserInfo user);
Builds a custom avatar widget for the current user (used in the input field).
Return null to fallback to the default avatar.
Widget? buildUserAvatar(BuildContext context, UserInfo user);