DefaultCommentsAppActions class

Default implementation of CommentsAppActions using Flutter's standard widgets.

Implemented types

Constructors

DefaultCommentsAppActions()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

buildCommentAvatar(BuildContext context, Comment comment) Widget?
Builds a custom avatar widget for the given comment.
override
buildUserAvatar(BuildContext context, UserInfo user) Widget?
Builds a custom avatar widget for the current user (used in the input field).
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
showConfirmationDialog({required BuildContext context, required String title, required String message, required String confirmText, required String cancelText, required void onConfirm(bool)}) → void
Shows a confirmation dialog.
override
showErrorSnackbar(BuildContext context, String message) → void
Shows an error snackbar with the given message.
override
showInfoSnackbar(BuildContext context, String message) → void
Shows an info snackbar with the given message.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited