buildCommentAvatar method
Builds a custom avatar widget for the given comment.
Return null to fallback to the default avatar.
Implementation
@override
Widget? buildCommentAvatar(BuildContext context, Comment comment) => null;
Builds a custom avatar widget for the given comment.
Return null to fallback to the default avatar.
@override
Widget? buildCommentAvatar(BuildContext context, Comment comment) => null;