buildUserAvatar method
Builds a custom avatar widget for the current user (used in the input field).
Return null to fallback to the default avatar.
Implementation
@override
Widget? buildUserAvatar(BuildContext context, UserInfo user) => null;
Builds a custom avatar widget for the current user (used in the input field).
Return null to fallback to the default avatar.
@override
Widget? buildUserAvatar(BuildContext context, UserInfo user) => null;