CommentsTextStyle class abstract

Text style configuration for comments widgets.

This interface allows customization of text styles used in the comments package. If not provided, the package will use default styles based on the current Theme.

Implementers

Constructors

CommentsTextStyle()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

bold18({Color? color, TextAlign? align}) TextStyle
Style for bold 18pt text (typically used for titles).
normal12({Color? color, TextAlign? align}) TextStyle
Style for normal 12pt text.
normal14({Color? color, TextAlign? align}) TextStyle
Style for normal 14pt text.
normal15({Color? color, TextAlign? align}) TextStyle
Style for normal 15pt text.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited