CommentsTheme class abstract
Theme configuration for the comments package.
This interface allows customization of colors and styling used throughout the comments widgets. If not provided, the package will use default values based on the current Theme from the BuildContext.
- Implementers
Constructors
Properties
- cardRadius → BorderRadius
-
Border radius for card elements.
no setter
- error → Color
-
Error color for delete actions and error messages.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- likeColor → Color
-
Color for like/heart icon when liked.
no setter
- mainBackground → Color
-
Main background color (typically used for text in dark mode).
no setter
- mainText → Color
-
Main text color (typically used for backgrounds in dark mode).
no setter
- minorText → Color
-
Minor text color for secondary text.
no setter
- primary → Color
-
Primary color used for avatars and accent elements.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited