DefaultCommentsTheme class
Default implementation of CommentsTheme that uses Theme.of.
This implementation extracts colors from the current Flutter theme, making it compatible with any Material Design theme.
- Implemented types
Constructors
- DefaultCommentsTheme(BuildContext context)
-
const
Properties
- cardRadius → BorderRadius
-
Border radius for card elements.
no setteroverride
- context → BuildContext
-
final
- error → Color
-
Error color for delete actions and error messages.
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- likeColor → Color
-
Color for like/heart icon when liked.
no setteroverride
- mainBackground → Color
-
Main background color (typically used for text in dark mode).
no setteroverride
- mainText → Color
-
Main text color (typically used for backgrounds in dark mode).
no setteroverride
- minorText → Color
-
Minor text color for secondary text.
no setteroverride
- primary → Color
-
Primary color used for avatars and accent elements.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited