UserInfo class
Information about the current user.
This class holds basic user information needed for comment operations.
Example:
const user = UserInfo(
uuid: 'user-123',
name: 'John Doe',
);
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- initials → String
-
Gets the user's initials for display in avatars.
no setter
- name → String
-
Display name of the user.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- uuid → String
-
Unique identifier for the user.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited