setReplyTo method

void setReplyTo(
  1. Comment? comment
)

Sets the comment to reply to.

When a user starts replying to a comment, call this method with that comment. Set to null to cancel the reply.

comment is the comment to reply to, or null to clear the reply target.

Implementation

void setReplyTo(Comment? comment) {
  _replyingTo = comment;
  notifyListeners();
}