CommentReportProvider constructor

CommentReportProvider(
  1. CommentService service,
  2. dynamic onUserBlocked()
)

Creates a new CommentReportProvider.

service is used to send the report to the server. onUserBlocked is called when a user is successfully blocked.

Implementation

CommentReportProvider(this.service, this.onUserBlocked);