ReportReason class

A reason for reporting a comment.

Each report reason has an ID (used for server communication) and a label (displayed to the user).

Example:

const reason = ReportReason('spam', 'Spam or misleading content');

Constructors

ReportReason(String id, String label)
Creates a new ReportReason.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
Unique identifier for this report reason.
final
label String
Human-readable label for this report reason.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited