id property
Unique identifier for this report reason.
This ID is sent to the server when submitting a report.
Implementation
final String id;
Unique identifier for this report reason.
This ID is sent to the server when submitting a report.
final String id;