label property
Human-readable label for this report reason.
This is displayed to the user in the report dialog.
Implementation
final String label;
Human-readable label for this report reason.
This is displayed to the user in the report dialog.
final String label;