CommentConfig class
Configuration for the comments module.
This class holds configuration settings that affect comment behavior, such as the list of bad words to filter.
Example:
const config = CommentConfig(
badWords: 'bad\nword\ntest\n# This is a comment',
);
Constructors
- CommentConfig({required String badWords})
-
Creates a new CommentConfig.
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited