CommentsAppActions class abstract

Callbacks for app-level actions like showing snackbars and dialogs.

This interface allows the comments package to interact with the host app for displaying messages and confirmation dialogs. If not provided, the package will use default Flutter implementations.

Implementers

Constructors

CommentsAppActions()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

buildCommentAvatar(BuildContext context, Comment comment) Widget?
Builds a custom avatar widget for the given comment.
buildUserAvatar(BuildContext context, UserInfo user) Widget?
Builds a custom avatar widget for the current user (used in the input field).
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
showConfirmationDialog({required BuildContext context, required String title, required String message, required String confirmText, required String cancelText, required void onConfirm(bool)}) → void
Shows a confirmation dialog.
showErrorSnackbar(BuildContext context, String message) → void
Shows an error snackbar with the given message.
showInfoSnackbar(BuildContext context, String message) → void
Shows an info snackbar with the given message.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited