DefaultCommentsTextStyle class
Default implementation of CommentsTextStyle using Theme.of.
- Implemented types
Constructors
- DefaultCommentsTextStyle(BuildContext context)
-
const
Properties
- context → BuildContext
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
bold18(
{Color? color, TextAlign? align}) → TextStyle -
Style for bold 18pt text (typically used for titles).
override
-
normal12(
{Color? color, TextAlign? align}) → TextStyle -
Style for normal 12pt text.
override
-
normal14(
{Color? color, TextAlign? align}) → TextStyle -
Style for normal 14pt text.
override
-
normal15(
{Color? color, TextAlign? align}) → TextStyle -
Style for normal 15pt text.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited