replyingTo property
Comment?
get
replyingTo
The comment that the user is currently replying to.
Returns null if the user is not replying to any comment.
Implementation
Comment? get replyingTo => _replyingTo;