CommentService class abstract
Service interface for comment operations
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
deleteComment(
String commentId) → Future< void> - Delete a comment
-
fetchComments(
String entityId, CommentConfig config, int page) → Future< List< Comment> > - Fetch comments for an entity
-
fetchReplies(
String commentId, int page) → Future< List< Comment> > - Fetch replies for a comment
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
postComment(
Comment comment, CommentConfig config) → Future< Comment?> - Post a new comment
-
postReply(
Comment comment) → Future< Comment?> - Post a reply to a comment
-
sendBlockUser(
String userId) → Future< void> - Block a user
-
sendReportComment(
String commentId, String reasonId) → Future< void> - Send a report for a comment
-
sendReportUser(
String userId) → Future< void> - Send a report for a user
-
toggleLikeComment(
String commentId) → Future< Comment?> - Toggle like on a comment
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited